.. _running_eddymotion:

Running *Eddymotion*
********************
Command line interface
----------------------
.. argparse::
   :ref: eddymotion.cli.parser._build_parser
   :prog: eddymotion
   :nodefault:
   :nodefaultconst: